@@ -1,5 +1,6 @@
 export default {
   common: {
+    outboundSetting: "出站设置",
     setting: "设置",
     about: "关于",
     loggedAs: "正在以 <b>{username}</b> 的身份登录",
@@ -114,12 +115,12 @@ export default {
     portSharingOn: "开启端口分享",
     concurrency: "最大并发数",
     options: {
-      global: "代理所有流量",
+      global: "不进行分流",
       direct: "直连模式",
       pac: "跟随规则端口",
-      whitelistCn: "大陆白名单",
-      gfwlist: "GFWList",
-      sameAsPacMode: "与规则端口所选模式一致",
+      whitelistCn: "大陆白名单模式",
+      gfwlist: "GFWList模式",
+      sameAsPacMode: "分流规则与规则端口所选模式一致",
       customRouting: "自定义路由规则",
       antiDnsHijack: "仅防止DNS劫持(快速)",
       forwardDnsRequest: "转发DNS请求",
@@ -133,7 +134,8 @@ export default {
       updateGfwlistAtIntervals: "每隔一段时间更新GFWList（单位：小时）",
       dependTransparentMode: "跟随透明代理/系统代理",
       closed: "关闭",
-      advanced: "自定义高级设置"
+      advanced: "自定义高级设置",
+      leastPing: "最小时延优先"
     },
     messages: {
       gfwlist: "该时间是指本地文件最后修改时间，因此可能会领先最新版本",
@@ -156,8 +158,11 @@ export default {
                           <p>当前设置的端口白名单为：</p>
                           <p>TCP: {tcpPorts}</p>
                           <p>UDP: {udpPorts}</p>`,
-      xtlsNotWithWs: `xtls无法和websocket共存`,
-      grpcShouldWithTls: `gRPC必须启用TLS`
+      grpcShouldWithTls: `gRPC必须启用TLS`,
+      ssPluginImpl:
+        "★默认：使用 simple-obfs 时为等效传输层，v2ray-plugin 时为链式。" +
+        "★链式：shadowsocks 流量会被转发至独立的插件。" +
+        "★等效传输层：直接由 v2ray/xray 核心的传输层处理。"
     }
   },
   customAddressPort: {
@@ -167,8 +172,8 @@ export default {
     portHttp: "http端口",
     portSocks5WithPac: "socks5端口(带分流规则)",
     portHttpWithPac: "http端口(带分流规则)",
-    portVlessGrpc: "VLESS-GRPC端口(带分流规则)",
-    portVlessGrpcLink: "VLESS-GRPC端口链接",
+    portVmess: "VMess端口(带分流规则)",
+    portVmessLink: "VMess端口链接",
     messages: [
       "如需修改后端运行地址(默认0.0.0.0:2017)，可添加环境变量<code>V2RAYA_ADDRESS</code>或添加启动参数<code>--address</code>。",
       "docker模式下如果未使用<code>--privileged --network host</code>参数启动容器，可通过修改端口映射修改socks5、http端口。",
@@ -265,9 +270,11 @@ export default {
   },
   version: {
     higherVersionNeeded: "该操作需要 v2rayA 的版本高于{version}",
-    v2rayInvalid: "检测到 geosite.dat, geoip.dat 文件或 v2ray-core 可能未正确安装，请检查"
+    v2rayInvalid: "检测到 geosite.dat, geoip.dat 文件或 v2ray-core 可能未正确安装，请检查",
+    v2rayNotV5:
+      "检测到 v2ray-core 的版本并非 v5，请使用 v5 版本或将 v2rayA 降级至 v1.5"
   },
-  about: `<p>v2rayA是V2Ray的一个Web客户端，前端使用Vue.js构建，后端使用Golang构建。</p>
+  about: `<p>v2rayA 是 V2Ray 的一个 Web 客户端。</p>
           <p class="about-small">默认端口：</p>
           <p class="about-small">2017: v2rayA后端端口</p>
           <p class="about-small">20170: SOCKS协议</p>
@@ -275,8 +282,8 @@ export default {
           <p class="about-small">20172: 带分流规则的HTTP协议</p>
           <p class="about-small">其他端口：</p>
           <p class="about-small">32345: tproxy，透明代理所需 </p>
-          <p class="about-small">32346: 插件协议端口，如trojan、ssr和pingtunnel</p>
-          <p>在使用中如果发现任何问题，欢迎<a href="https://github.com/v2rayA/v2rayA/issues">提出issue</a>。</p>`,
+          <p>在使用中如果发现任何问题，欢迎<a href="https://github.com/v2rayA/v2rayA/issues">提出issue</a>.</p>
+          <p>文档：<a href="https://v2raya.org">https://v2raya.org</a>.</p>`,
   axios: {
     messages: {
       optimizeBackend: "您是否需要调整服务端地址？",
@@ -287,8 +294,7 @@ export default {
       ]
     },
     urls: {
-      usage:
-        "https://github.com/v2rayA/v2rayA/wiki/%E4%BD%BF%E7%94%A8%E6%96%B9%E6%B3%95"
+      usage: "https://v2raya.org/"
     }
   },
   routingA: {
