@@ -7,7 +7,7 @@ import "@/plugins/virtual-scroll";
 import Vue from "vue";
 import "normalize.css";
 // import "@/registerServiceWorker";
-import "@/assets/pace-progressbar";
-import "@/assets/pace-progressbar/themes/blue/pace-theme-corner-indicator.css";
+import "pace-js";
+import "pace-js/themes/blue/pace-theme-corner-indicator.css";
 
 Vue.config.productionTip = false;
