@@ -2,7 +2,7 @@ package httpClient
 
 import (
 	"fmt"
-	"github.com/v2rayA/v2rayA/global"
+	"github.com/v2rayA/v2rayA/conf"
 	"net/http"
 )
 
@@ -12,7 +12,7 @@ func HttpGetUsingSpecificClient(c *http.Client, url string) (resp *http.Response
 		return
 	}
 	//shadowrocket会有可能不清楚alterid的情况，影响aead是否启用的问题
-	req.Header.Set("User-Agent", fmt.Sprintf("v2rayA/%v WebRequestHelper", global.Version))
+	req.Header.Set("User-Agent", fmt.Sprintf("v2rayA/%v WebRequestHelper", conf.Version))
 	if resp, err = c.Do(req); err != nil {
 		resp, err = http.DefaultClient.Do(req)
 	}
