@@ -3,11 +3,10 @@ package main
 import (
 	"fmt"
 	"github.com/gin-gonic/gin"
-	jsoniter "github.com/json-iterator/go"
 	jsonIteratorExtra "github.com/json-iterator/go/extra"
 	"github.com/v2rayA/v2rayA/common/netTools/ports"
 	"github.com/v2rayA/v2rayA/conf"
-	"github.com/v2rayA/v2rayA/core/serverObj"
+	"github.com/v2rayA/v2rayA/core/ipforward"
 	"github.com/v2rayA/v2rayA/core/v2ray"
 	"github.com/v2rayA/v2rayA/core/v2ray/asset"
 	"github.com/v2rayA/v2rayA/core/v2ray/asset/dat"
@@ -15,19 +14,27 @@ import (
 	"github.com/v2rayA/v2rayA/core/v2ray/where"
 	"github.com/v2rayA/v2rayA/db"
 	"github.com/v2rayA/v2rayA/db/configure"
+	"github.com/v2rayA/v2rayA/pkg/util/copyfile"
 	"github.com/v2rayA/v2rayA/pkg/util/log"
 	"github.com/v2rayA/v2rayA/server/router"
 	"github.com/v2rayA/v2rayA/server/service"
 	"net"
 	"os"
 	"os/signal"
-	"path"
+	"path/filepath"
 	"runtime"
 	"sync"
 	"syscall"
 	"time"
 )
 
+import (
+	confv4 "github.com/v2rayA/v2rayA-lib4/conf"
+	touchv4 "github.com/v2rayA/v2rayA-lib4/core/touch"
+	configurev4 "github.com/v2rayA/v2rayA-lib4/db/configure"
+	servicev4 "github.com/v2rayA/v2rayA-lib4/server/service"
+)
+
 func checkEnvironment() {
 	config := conf.GetEnvironmentConfig()
 	if len(config.PrintReport) > 0 {
@@ -82,29 +89,6 @@ func checkTProxySupportability() {
 	}
 }
 
-func migrate(jsonConfPath string) (err error) {
-	log.Info("Migrating json to nutsdb...")
-	defer func() {
-		if err != nil {
-			log.Warn("Migrating failed: %v", err)
-		} else {
-			log.Info("Migrating complete")
-		}
-	}()
-	b, err := os.ReadFile(jsonConfPath)
-	if err != nil {
-		return
-	}
-	var cfg configure.Configure
-	if err = jsoniter.Unmarshal(b, &cfg); err != nil {
-		return
-	}
-	if err = configure.SetConfigure(&cfg); err != nil {
-		return
-	}
-	return nil
-}
-
 func initDBValue() {
 	log.Info("init DB")
 	err := configure.SetConfigure(configure.New())
@@ -113,93 +97,68 @@ func initDBValue() {
 	}
 }
 
-func migrateServerFormat() {
-	serverRaw := configure.GetServers()
-	var serverRawV2 []*configure.ServerRawV2
-	for _, raw := range serverRaw {
-		if raw.VmessInfo.Protocol == "" {
-			raw.VmessInfo.Protocol = "vmess"
-		}
-		obj, err := serverObj.NewFromLink(raw.VmessInfo.Protocol, raw.VmessInfo.ExportToURL())
-		if err != nil {
-			log.Warn("failed to migrate: %v", raw.VmessInfo.Ps)
-			continue
-		}
-		serverRawV2 = append(serverRawV2, &configure.ServerRawV2{
-			ServerObj: obj,
-			Latency:   raw.Latency,
-		})
-	}
-	if len(serverRawV2) > 0 {
-		err := configure.AppendServers(serverRawV2)
-		if err != nil {
-			log.Warn("failed to migrate: %v", err)
-		}
-	}
-	subscriptionsRaw := configure.GetSubscriptions()
-	var subV2 []*configure.SubscriptionRawV2
-	for _, raw := range subscriptionsRaw {
-		var serversV2 []configure.ServerRawV2
-		for _, sraw := range raw.Servers {
-			if sraw.VmessInfo.Protocol == "" {
-				sraw.VmessInfo.Protocol = "vmess"
-			}
-			obj, err := serverObj.NewFromLink(sraw.VmessInfo.Protocol, sraw.VmessInfo.ExportToURL())
-			if err != nil {
-				log.Warn("failed to migrate: %v", sraw.VmessInfo.Ps)
-				continue
-			}
-			serversV2 = append(serversV2, configure.ServerRawV2{
-				ServerObj: obj,
-				Latency:   sraw.Latency,
-			})
-		}
-		subRawV2 := configure.SubscriptionRawV2{
-			Remarks: raw.Remarks,
-			Address: raw.Address,
-			Status:  raw.Status,
-			Servers: serversV2,
-			Info:    raw.Info,
-		}
-		subV2 = append(subV2, &subRawV2)
-	}
-	if len(subV2) > 0 {
-		err := configure.AppendSubscriptions(subV2)
-		if err != nil {
-			log.Warn("failed to migrate: %v", err)
-		}
-	}
-}
-
 func initConfigure() {
 	//初始化配置
 	jsonIteratorExtra.RegisterFuzzyDecoders()
 
 	//db
-	if configure.IsConfigureNotExists() {
+	dbPath := filepath.Join(conf.GetEnvironmentConfig().Config, "bolt.db")
+	if _, e := os.Lstat(dbPath); os.IsNotExist(e) {
+		//confv4.SetConfig(confv4.Params{Config: conf.GetEnvironmentConfig().Config})
 		// need to migrate?
-		camp := []string{path.Join(conf.GetEnvironmentConfig().Config, "v2raya.json"), "/etc/v2ray/v2raya.json", "/etc/v2raya/v2raya.json"}
-		var success bool
-		for _, jsonConfPath := range camp {
-			if _, err := os.Stat(jsonConfPath); err == nil {
-				log.Info("migrate from %v", jsonConfPath)
-				err = migrate(jsonConfPath)
-				if err == nil {
-					success = true
-					break
+		if !configurev4.IsConfigureNotExists() {
+			// There is different format in server and subscription.
+			// So we keep other content and reimport servers and subscriptions.
+			log.Warn("Migrating from v4 to feat_v5")
+			if err := copyfile.CopyFileContent(filepath.Join(
+				confv4.GetEnvironmentConfig().Config,
+				"boltv4.db",
+			), filepath.Join(
+				conf.GetEnvironmentConfig().Config,
+				"bolt.db",
+			)); err != nil {
+				log.Fatal("Failed to copy boltv4.db to bolt.db: %v", err)
+			}
+
+			// clear connects of outbounds
+			for _, out := range configure.GetOutbounds() {
+				_ = configure.ClearConnects(out)
+			}
+			var indexes []int
+			for i := 0; i < configurev4.GetLenServers(); i++ {
+				indexes = append(indexes, i)
+			}
+			_ = configure.RemoveServers(indexes)
+
+			indexes = nil
+			for i := 0; i < configurev4.GetLenSubscriptions(); i++ {
+				indexes = append(indexes, i)
+			}
+			_ = configure.RemoveSubscriptions(indexes)
+
+			// migrate servers and subscriptions
+			t := touchv4.GenerateTouch()
+			subs := configurev4.GetSubscriptionsV2()
+			for _, sub := range subs {
+				log.Info("Importing subscription: %v", sub.Address)
+				if e := service.Import(sub.Address, nil); e != nil {
+					log.Warn("Failed to migrate subscription: %v", sub.Address)
 				}
 			}
-		}
-		if !success {
+			for iSvr := range t.Servers {
+				if addr, e := servicev4.GetSharingAddress(&configurev4.Which{
+					TYPE: configurev4.ServerType,
+					ID:   iSvr + 1,
+				}); e == nil {
+					if e := service.Import(addr, nil); e != nil {
+						log.Warn("Failed to migrate server: %v", addr)
+					}
+				}
+			}
+			log.Warn("Migration is done")
+		} else {
 			initDBValue()
 		}
-	} else {
-		// need to migrate server format from v1 to v2?
-		if (len(configure.GetServers())+len(configure.GetSubscriptions())) > 0 &&
-			(len(configure.GetServersV2())+len(configure.GetSubscriptionsV2())) == 0 {
-			log.Info("migrating server format from v1 to v2...")
-			migrateServerFormat()
-		}
 	}
 	//检查config.json是否存在
 	if _, err := os.Stat(asset.GetV2rayConfigPath()); err != nil {
@@ -261,7 +220,7 @@ func hello() {
 }
 
 func updateSubscriptions() {
-	subs := configure.GetSubscriptionsV2()
+	subs := configure.GetSubscriptions()
 	lenSubs := len(subs)
 	control := make(chan struct{}, 2) //并发限制同时更新2个订阅
 	wg := new(sync.WaitGroup)
@@ -357,6 +316,15 @@ func checkUpdate() {
 func run() (err error) {
 	//判别需要启动v2ray吗
 	if configure.GetRunning() {
+		//configure the ip forward
+		setting := service.GetSetting()
+		if setting.IpForward != ipforward.IsIpForwardOn() {
+			e := ipforward.WriteIpForward(setting.IpForward)
+			if e != nil {
+				log.Warn("Connect: %v", e)
+			}
+		}
+		// Start.
 		err := v2ray.UpdateV2RayConfig()
 		if err != nil {
 			log.Error("failed to start v2ray-core: %v", err)
