@@ -39,11 +39,11 @@ func PutSetting(ctx *gin.Context) {
 	var data configure.Setting
 	err := ctx.ShouldBindJSON(&data)
 	if err != nil {
-		common.ResponseError(ctx, logError(err, "bad request"))
+		common.ResponseError(ctx, logError("bad request"))
 		return
 	}
 	if data.MuxOn == configure.Yes && (data.Mux < 1 || data.Mux > 1024) {
-		common.ResponseError(ctx, logError(nil, "mux should be between 1 and 1024"))
+		common.ResponseError(ctx, logError("mux should be between 1 and 1024"))
 		return
 	}
 	err = service.UpdateSetting(&data)
